@@ -36,17 +36,12 @@ class WavClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateChannelCode", params)
+            headers = request.headers
+            body = self.call("CreateChannelCode", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateChannelCodeResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.CreateChannelCodeResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -64,17 +59,35 @@ class WavClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateCorpTag", params)
+            headers = request.headers
+            body = self.call("CreateCorpTag", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateCorpTagResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.CreateCorpTagResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreateLead(self, request):
+        """线索回收接口
+
+        :param request: Request instance for CreateLead.
+        :type request: :class:`tencentcloud.wav.v20210129.models.CreateLeadRequest`
+        :rtype: :class:`tencentcloud.wav.v20210129.models.CreateLeadResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateLead", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateLeadResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -92,17 +105,12 @@ class WavClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("QueryActivityJoinList", params)
+            headers = request.headers
+            body = self.call("QueryActivityJoinList", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.QueryActivityJoinListResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.QueryActivityJoinListResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -120,17 +128,12 @@ class WavClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("QueryActivityList", params)
+            headers = request.headers
+            body = self.call("QueryActivityList", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.QueryActivityListResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.QueryActivityListResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -148,17 +151,12 @@ class WavClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("QueryActivityLiveCodeList", params)
+            headers = request.headers
+            body = self.call("QueryActivityLiveCodeList", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.QueryActivityLiveCodeListResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.QueryActivityLiveCodeListResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -176,17 +174,12 @@ class WavClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("QueryChannelCodeList", params)
+            headers = request.headers
+            body = self.call("QueryChannelCodeList", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.QueryChannelCodeListResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.QueryChannelCodeListResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -204,17 +197,104 @@ class WavClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("QueryChatArchivingList", params)
+            headers = request.headers
+            body = self.call("QueryChatArchivingList", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.QueryChatArchivingListResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.QueryChatArchivingListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def QueryClueInfoList(self, request):
+        """企业可通过此接口获取线索列表。
+
+        :param request: Request instance for QueryClueInfoList.
+        :type request: :class:`tencentcloud.wav.v20210129.models.QueryClueInfoListRequest`
+        :rtype: :class:`tencentcloud.wav.v20210129.models.QueryClueInfoListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("QueryClueInfoList", params, headers=headers)
+            response = json.loads(body)
+            model = models.QueryClueInfoListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def QueryCrmStatistics(self, request):
+        """通过接口拉取租户/指定成员/部门在指定日期范围内的CRM跟进统计数据
+
+        :param request: Request instance for QueryCrmStatistics.
+        :type request: :class:`tencentcloud.wav.v20210129.models.QueryCrmStatisticsRequest`
+        :rtype: :class:`tencentcloud.wav.v20210129.models.QueryCrmStatisticsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("QueryCrmStatistics", params, headers=headers)
+            response = json.loads(body)
+            model = models.QueryCrmStatisticsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def QueryCustomerEventDetailStatistics(self, request):
+        """通过接口拉取SaaS内C端外部联系人在指定时间范围内的行为事件明细。此接口提供的数据以天为维度，查询的时间范围为[start_time,end_time]，即前后均为闭区间，支持的最大查询跨度为365天。
+
+        :param request: Request instance for QueryCustomerEventDetailStatistics.
+        :type request: :class:`tencentcloud.wav.v20210129.models.QueryCustomerEventDetailStatisticsRequest`
+        :rtype: :class:`tencentcloud.wav.v20210129.models.QueryCustomerEventDetailStatisticsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("QueryCustomerEventDetailStatistics", params, headers=headers)
+            response = json.loads(body)
+            model = models.QueryCustomerEventDetailStatisticsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def QueryDealerInfoList(self, request):
+        """企业可通过此接口获取录入在企微SaaS平台上的经销商信息。
+
+        :param request: Request instance for QueryDealerInfoList.
+        :type request: :class:`tencentcloud.wav.v20210129.models.QueryDealerInfoListRequest`
+        :rtype: :class:`tencentcloud.wav.v20210129.models.QueryDealerInfoListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("QueryDealerInfoList", params, headers=headers)
+            response = json.loads(body)
+            model = models.QueryDealerInfoListResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -223,7 +303,7 @@ class WavClient(AbstractClient):
 
 
     def QueryExternalContactDetail(self, request):
-        """企业可通过此接口，根据外部联系人的userid，拉取客户详情
+        """企业可通过此接口，根据外部联系人的userid，拉取外部联系人详情
 
         :param request: Request instance for QueryExternalContactDetail.
         :type request: :class:`tencentcloud.wav.v20210129.models.QueryExternalContactDetailRequest`
@@ -232,17 +312,12 @@ class WavClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("QueryExternalContactDetail", params)
+            headers = request.headers
+            body = self.call("QueryExternalContactDetail", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.QueryExternalContactDetailResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.QueryExternalContactDetailResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -251,7 +326,7 @@ class WavClient(AbstractClient):
 
 
     def QueryExternalContactList(self, request):
-        """企业可通过此接口获取指定成员添加的客户列表。客户是指配置了客户联系功能的成员所添加的外部联系人。没有配置客户联系功能的成员，所添加的外部联系人将不会作为客户返回。
+        """企业可通过此接口基于外部联系人获取指定成员添加的客户列表。客户是指配置了客户联系功能的成员所添加的外部联系人。没有配置客户联系功能的成员，所添加的外部联系人将不会作为客户返回。
 
         :param request: Request instance for QueryExternalContactList.
         :type request: :class:`tencentcloud.wav.v20210129.models.QueryExternalContactListRequest`
@@ -260,17 +335,35 @@ class WavClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("QueryExternalContactList", params)
+            headers = request.headers
+            body = self.call("QueryExternalContactList", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.QueryExternalContactListResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.QueryExternalContactListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def QueryExternalUserEventList(self, request):
+        """通过接口拉取租户在指定时间范围内的外部联系人添加/删除明细，此接口提供的数据以天为维度，查询的时间范围为[StarTime, EndTime]，即前后均为闭区间，支持的最大查询跨度为365天；
+
+        :param request: Request instance for QueryExternalUserEventList.
+        :type request: :class:`tencentcloud.wav.v20210129.models.QueryExternalUserEventListRequest`
+        :rtype: :class:`tencentcloud.wav.v20210129.models.QueryExternalUserEventListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("QueryExternalUserEventList", params, headers=headers)
+            response = json.loads(body)
+            model = models.QueryExternalUserEventListResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -288,17 +381,12 @@ class WavClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("QueryExternalUserMappingInfo", params)
+            headers = request.headers
+            body = self.call("QueryExternalUserMappingInfo", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.QueryExternalUserMappingInfoResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.QueryExternalUserMappingInfoResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -316,17 +404,35 @@ class WavClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("QueryLicenseInfo", params)
+            headers = request.headers
+            body = self.call("QueryLicenseInfo", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.QueryLicenseInfoResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.QueryLicenseInfoResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def QueryMaterialList(self, request):
+        """通过接口按类型拉取租户当前的素材列表及关键信息
+
+        :param request: Request instance for QueryMaterialList.
+        :type request: :class:`tencentcloud.wav.v20210129.models.QueryMaterialListRequest`
+        :rtype: :class:`tencentcloud.wav.v20210129.models.QueryMaterialListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("QueryMaterialList", params, headers=headers)
+            response = json.loads(body)
+            model = models.QueryMaterialListResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -344,17 +450,81 @@ class WavClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("QueryMiniAppCodeList", params)
+            headers = request.headers
+            body = self.call("QueryMiniAppCodeList", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.QueryMiniAppCodeListResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.QueryMiniAppCodeListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def QueryStaffEventDetailStatistics(self, request):
+        """通过接口拉取SaaS内企业成员在指定时间范围内的行为事件明细。此接口提供的数据以天为维度，查询的时间范围为[start_time,end_time]，即前后均为闭区间，支持的最大查询跨度为365天。
+
+        :param request: Request instance for QueryStaffEventDetailStatistics.
+        :type request: :class:`tencentcloud.wav.v20210129.models.QueryStaffEventDetailStatisticsRequest`
+        :rtype: :class:`tencentcloud.wav.v20210129.models.QueryStaffEventDetailStatisticsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("QueryStaffEventDetailStatistics", params, headers=headers)
+            response = json.loads(body)
+            model = models.QueryStaffEventDetailStatisticsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def QueryUserInfoList(self, request):
+        """查询企业成员信息列表接口
+
+        :param request: Request instance for QueryUserInfoList.
+        :type request: :class:`tencentcloud.wav.v20210129.models.QueryUserInfoListRequest`
+        :rtype: :class:`tencentcloud.wav.v20210129.models.QueryUserInfoListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("QueryUserInfoList", params, headers=headers)
+            response = json.loads(body)
+            model = models.QueryUserInfoListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def QueryVehicleInfoList(self, request):
+        """企业可通过此接口获取企微SaaS平台上的车系车型信息。
+
+        :param request: Request instance for QueryVehicleInfoList.
+        :type request: :class:`tencentcloud.wav.v20210129.models.QueryVehicleInfoListRequest`
+        :rtype: :class:`tencentcloud.wav.v20210129.models.QueryVehicleInfoListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("QueryVehicleInfoList", params, headers=headers)
+            response = json.loads(body)
+            model = models.QueryVehicleInfoListResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
